==> blue2-theme-gneiss-energy-2019-1.0.5-a99a77.tar: templates/sections/form.php <==
<section class="section--form" style="background-image: url(<?=get_sub_field('background_image');?>)">
    <div class="gneiss-container">
        <div class="row">
            <div class="col-12">
                <h2><?=get_sub_field('title');?></h2>
                <hr>
                <?php echo do_shortcode( get_sub_field('contact_form_shortcode'), false ); ?>
            </div>
        </div>
    </div>
    <span class="graphic-device graphic-device--right aos-init aos-animate rock-striation" data-aos="fade-left" data-aos-duration="3000">
        <img src="<?=get_template_directory_uri();?>/dist/images/striation-graphic-float.svg" alt="graphic device left">
    </span>
</section>
<section class="section--map">
    <div class="row">        
        <div class="col-md-6 map-container">
            <div class="map-info-container">
                <div class="map-info">
                    <h2>London Office</h2>
                    <hr>
                    <div class="col-xs-12 col-sm-6 map-info-left">
                        <p>12 Hay Hill, Mayfair</p>
                        <p>London</p>
                        <p>W1J 6DQ</p>
                    </div>
                    <div class="col-xs-12 col-sm-6">
                    </div>
                    <div class="col-xs-12 map-info-bottom">
                        <a id="directions-london" href="https://www.google.com/maps/place/Marfin+Popular+Bank,+12+Hay+Hill,+Mayfair,+London+W1J+6DQ/@51.5091583,-0.146063,17z/data=!3m1!4b1!4m5!3m4!1s0x4876052982b3ea77:0x7f34ff440ed37974!8m2!3d51.509155!4d-0.143869" target="_blank">
                            <p><i class="fal fa-map-marker-alt"></i>GET DIRECTIONS</p>
                        </a>
                    </div>
                </div>
            </div>
            <div id="map-left">
            </div>
        </div>
        <div class="col-md-6 map-container">
            <div class="map-info-container">
                <div class="map-info">
                    <h2>Edinburgh Office</h2>
                    <hr>
                    <div class="col-xs-12 col-sm-6 map-info-left">
                        <p>5A Rothesay Place</p>
                        <p>Edinburgh</p>
                        <p>EH3 7SL</p>
                    </div>
                    <div class="col-xs-12 col-sm-6">
                    </div>
                    <div class="col-xs-12 map-info-bottom">
                        <a id="directions-edinburgh" href="https://www.google.com/maps/place/5a+Rothesay+Pl,+Edinburgh+EH3+7SL/@55.9508292,-3.2189073,17z/data=!3m1!4b1!4m5!3m4!1s0x4887c7bb23104b9f:0xc54c80f6354375e9!8m2!3d55.9508262!4d-3.2167133" target="_blank">
                            <p><i class="fal fa-map-marker-alt"></i>GET DIRECTIONS</p>
                        </a>
                    </div>
                </div>
            </div>
            <div id="map-right">
            </div>
        </div>
    </div>
</section>

==> blue2-theme-gneiss-energy-2019-10.0.42-631076.tar: templates/sections/form.php <==
<section class="section--form" style="background-image: url(<?=get_sub_field('background_image');?>)">
    <div class="gneiss-container">
        <div class="row">
            <div class="col-12">
                <h2><?=get_sub_field('title');?></h2>
                <hr>
                <?php echo do_shortcode( get_sub_field('contact_form_shortcode'), false ); ?>
            </div>
        </div>
    </div>
    <span class="graphic-device graphic-device--right aos-init aos-animate rock-striation" data-aos="fade-left" data-aos-duration="3000">
        <img src="<?=get_template_directory_uri();?>/dist/images/striation-graphic-float.svg" alt="graphic device left">
    </span>
</section>
<section class="section--map">
    <div class="row">        
        <div class="col-md-6 map-container">
            <div class="map-info-container">
                <div class="map-info">
                    <h2>London Office</h2>
                    <hr>
                    <div class="col-xs-12 col-sm-7 map-info-left">
                        <p>5th Floor, 64 North Row, Mayfair</p>
                        <p>London</p>
                        <p>W1K 7DA</p>
                    </div>
                    <div class="col-xs-12 col-sm-5">
                    </div>
                    <div class="col-xs-12 map-info-bottom">
                        <a id="directions-london" href="https://www.google.com/maps/place/Valad+Property+Group,+5th+Floor+64+N+Row,+Mayfair,+London+W1K+7LL/@51.513197,-0.1588834,17z/data=!3m1!4b1!4m5!3m4!1s0x487605331a241679:0xa5beb3b6a10ed676!8m2!3d51.513197!4d-0.1566947" target="_blank">
                            <p><i class="fal fa-map-marker-alt"></i>GET DIRECTIONS</p>
                        </a>
                    </div>
                </div>
            </div>
            <div id="map-left">
            </div>
        </div>
        <div class="col-md-6 map-container">
            <div class="map-info-container">
                <div class="map-info">
                    <h2>Edinburgh Office</h2>
                    <hr>
                    <div class="col-xs-12 col-sm-7 map-info-left">
                        <p>5A Rothesay Place</p>
                        <p>Edinburgh</p>
                        <p>EH3 7SL</p>
                    </div>
                    <div class="col-xs-12 col-sm-5">
                    </div>
                    <div class="col-xs-12 map-info-bottom">
                        <a id="directions-edinburgh" href="https://www.google.com/maps/place/5a+Rothesay+Pl,+Edinburgh+EH3+7SL/@55.9508292,-3.2189073,17z/data=!3m1!4b1!4m5!3m4!1s0x4887c7bb23104b9f:0xc54c80f6354375e9!8m2!3d55.9508262!4d-3.2167133" target="_blank">
                            <p><i class="fal fa-map-marker-alt"></i>GET DIRECTIONS</p>
                        </a>
                    </div>
                </div>
            </div>
            <div id="map-right">
            </div>
        </div>
    </div>
</section>
